/***************************************************************************
                          cspushbutton.cpp  -  description
                             -------------------
    begin                : Nov 6 2003
    copyright            : (C) 2003 by Gary Cramblitt
    email                : garycramblitt@comcast.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cspushbutton.h"
#include "clipspellconfig.h"

#include <kapplication.h>
#include <klocale.h>
#include <kiconloader.h>
#include <kpopupmenu.h>
#include <qtooltip.h>
#include <kspell.h>
#include <qclipboard.h>

CSPushButton::CSPushButton(QWidget *parent, const char *name )
    : KPushButton(parent,name)
{
    QPixmap pix = kapp->iconLoader()->loadIcon( "spellcheck", KIcon::Panel, KIcon::SizeSmall );
    setPixmap( pix );
    QToolTip::add( this, i18n("KClipSpellApplet - Clipboard Spellcheck") );
    connect( this, SIGNAL( clicked() ), this, SLOT( spellcheck() ) );
}

CSPushButton::~CSPushButton()
{
}

void CSPushButton::mousePressEvent( QMouseEvent* e )
{
    if( e->button() == Qt::LeftButton ) {
        spellcheck();
    }
    else if ( e->button() == Qt::RightButton ) {
        KPopupMenu* mnu = new KPopupMenu( this );
        mnu->insertTitle( i18n("KClipSpellApplet") );
        mnu->insertItem( i18n("&Spellcheck clipboard contents..."), this, SLOT( spellcheck() ) );
        mnu->insertItem( i18n("&Configure KSpell..."), this, SLOT( configureSpellcheck() ) );
        mnu->insertSeparator();
        mnu->insertItem( i18n("&About..."), this, SIGNAL( about() ) );
        mnu->popup( e->globalPos() );
    }
}

void CSPushButton::configureSpellcheck()
{
    // Display KSpell configuration dialog.  Save as global settings.
    ClipSpellConfig* cfgDlg = new ClipSpellConfig(this);
    cfgDlg->exec();
    delete cfgDlg;
}

void CSPushButton::spellcheck()
{
    // Get the clipboard object.        
    QClipboard *cb = kapp->clipboard();

    // Copy text from the clipboard.
    QString text = cb->text();
    if ( !text.isNull() ) {
//        qDebug( "The clipboard contains: " + text );
        // Spellcheck it.
        KSpell::modalCheck(text);
        // Copy corrected text into the clipboard.
        cb->setText( text );
    }
}

#include "cspushbutton.moc"
